<?php
/* 
** ZABBIX
** Copyright (C) 2000-2008 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/
?>
<?php
	global $TRANSLATION;

	$TRANSLATION=array(

	'S_DATE_FORMAT_YMDHMS'=>			'd M H:i:s',
	'S_DATE_FORMAT_YMD'=>			'd M Y',
	'S_HTML_CHARSET'=>			'UTF-8',
	'S_ACTIVATE_SELECTED'=>			'Activer les éléments sélectionnés',
	'S_DISABLE_SELECTED'=>			'Désactiver les éléments sélectionnés',
	'S_DELETE_SELECTED'=>			'Suppression sélections',
	'S_COPY_SELECTED_TO'=>			'Copier les éléments sélectionnés sur ...',
	'S_HOST_IP'=>			'ip hote',
	'S_SERVICE_TYPE'=>			'Type de service',
	'S_SERVICE_PORT'=>			'Port du service',
	'S_DISCOVERY_STATUS'=>			'Statut découverte',
	'S_RECEIVED_VALUE'=>			'Valeur reçue',
	'S_UPTIME_DOWNTIME'=>			'Uptime/Downtime',
	'S_DISCOVERY_RULE'=>			'Règle de découverte',
	'S_DISCOVERY'=>			'Découverte',
	'S_DISCOVERY_BIG'=>			'DECOUVERTE',
	'S_CONFIGURATION_OF_DISCOVERY'=>			'Configuration de la découverte',
	'S_CONFIGURATION_OF_DISCOVERY_BIG'=>			'CONFIGURATION DE LA DECOUVERTE',
	'S_NO_DISCOVERY_RULES_DEFINED'=>			'Aucune règle de découverte définie',
	'S_IP_RANGE'=>			'Plage d\'adresses IP',
	'S_INTERVALS'=>			'Intervals',
	'S_CHECKS'=>			'Vérifications',
	'S_ENABLE_SELECTED_RULES_Q'=>			'Activer les règles sélectionnées?',
	'S_DISABLE_SELECTED_RULES_Q'=>			'Desactiver les règles sélectionnées?',
	'S_DELETE_SELECTED_RULES_Q'=>			'Supprimer les règes sélectionnées?',
	'S_CREATE_RULE'=>			'Créer règle',
	'S_DELETE_RULE_Q'=>			'Supprimer règle?',
	'S_EVENT_SOURCE'=>			'Source événement',
	'S_NEW_CHECK'=>			'Nouvelle vérification',
	'S_SSH'=>			'SSH',
	'S_LDAP'=>			'LDAP',
	'S_SMTP'=>			'SMTP',
	'S_FTP'=>			'FTP',
	'S_HTTP'=>			'HTTP',
	'S_POP'=>			'POP',
	'S_NNTP'=>			'NNTP',
	'S_IMAP'=>			'IMAP',
	'S_TCP'=>			'TCP',
	'S_PORTS_SMALL'=>			'ports',
	'S_DISCOVERY_RULES_DELETED'=>			'Règles de découverte supprimées',
	'S_DISCOVERY_RULE_DELETED'=>			'Règle de découverte supprimée',
	'S_CANNOT_DELETE_DISCOVERY_RULE'=>			'Suppression règle de découverte impossible',
	'S_DISCOVERY_RULES_UPDATED'=>			'Règles de découverte modifiées',
	'S_DISCOVERY_RULE_UPDATED'=>			'Règle de découverte modifiée',
	'S_CANNOT_UPDATE_DISCOVERY_RULE'=>			'Modification règle impossible',
	'S_DISCOVERY_RULE_ADDED'=>			'Règle de découverte ajoutée',
	'S_CANNOT_ADD_DISCOVERY_RULE'=>			'Ajout règle de découverte impossible',
	'S_STATUS_OF_DISCOVERY_BIG'=>			'STATUT DE LA DECOUVERTE',
	'S_STATUS_OF_DISCOVERY'=>			'Statut de la découverte',
	'S_DETAILS_OF_SCENARIO'=>			'Details du scenario',
	'S_DETAILS_OF_SCENARIO_BIG'=>			'DETAILS DU SCENARIO',
	'S_SPEED'=>			'Vitesse',
	'S_RESPONSE_CODE'=>			'Code de réponse',
	'S_TOTAL_BIG'=>			'TOTAL',
	'S_RESPONSE_TIME'=>			'Temps de réponse',
	'S_IN_PROGRESS'=>			'En cours',
	'S_OF_SMALL'=>			'de',
	'S_IN_CHECK'=>			'En vérification',
	'S_IDLE_TILL'=>			'Idle till',
	'S_FAILED_ON'=>			'En échec',
	'S_STATUS_OF_WEB_MONITORING'=>			'Statut de la supervision Web',
	'S_STATUS_OF_WEB_MONITORING_BIG'=>			'STATUS DE LA SUPERVISION WEB',
	'S_STATE'=>			'Etat',
	'S_STATUS_CODES'=>			'Codes d\'état',
	'S_WEB'=>			'Web',
	'S_CONFIGURATION_OF_WEB_MONITORING'=>			'Configuration de la supervision Web',
	'S_CONFIGURATION_OF_WEB_MONITORING_BIG'=>			'CONFIGURATION DE LA SUPERVISION WEB',
	'S_SCENARIO'=>			'Scenario',
	'S_SCENARIOS'=>			'Scenarios',
	'S_SCENARIOS_BIG'=>			'SCENARIOS',
	'S_CREATE_SCENARIO'=>			'Créer scenario',
	'S_HIDE_DISABLED_SCENARIOS'=>			'Cacher les scenarios désactivés',
	'S_SHOW_DISABLED_SCENARIOS'=>			'Montrer les scénarios désactivés',
	'S_NUMBER_OF_STEPS'=>			'Nombre d\'étapes',
	'S_SCENARIO_DELETED'=>			'Scenario supprim',
	'S_SCENARIO_ACTIVATED'=>			'Scenario activ',
	'S_SCENARIO_DISABLED'=>			'Scenario désactivé',
	'S_ACTIVATE_SELECTED_SCENARIOS_Q'=>			'Activer les scénarios sélectionnés?',
	'S_DISABLE_SELECTED_SCENARIOS_Q'=>			'Désactiver les scénarios sélectionnés?',
	'S_DELETE_SELECTED_SCENARIOS_Q'=>			'Supprimer les scénarios sélectionnés?',
	'S_DELETE_SCENARIO_Q'=>			'Supprimer le scenario?',
	'S_CLEAN_HISTORY_SELECTED_SCENARIOS'=>			'Nettoyage historique pour les scénarios sélectionnés',
	'S_SCENARIO_UPDATED'=>			'Scenario modifi',
	'S_CANNOT_UPDATE_SCENARIO'=>			'Modification scenario impossible',
	'S_SCENARIO_ADDED'=>			'Scenario ajout',
	'S_CANNOT_ADD_SCENARIO'=>			'Ajout scenario impossible',
	'S_CANNOT_DELETE_SCENARIO'=>			'Suppression scenario impossible',
	'S_AGENT'=>			'Agent',
	'S_VARIABLES'=>			'Variables',
	'S_STEP'=>			'Etape',
	'S_STEPS'=>			'Etapes',
	'S_TIMEOUT'=>			'Timeout',
	'S_POST'=>			'Post',
	'S_REQUIRED'=>			'Requis',
	'S_STEP_OF_SCENARIO'=>			'Etape du scenario',
	'S_ELEMENT'=>			'Element',
	'S_ELEMENTS'=>			'Elements',
	'S_ONLY_HOST_INFO'=>			'Informations hotes seules',
	'S_EXPORT_IMPORT'=>			'Exporter/Importer',
	'S_IMPORT_FILE'=>			'Importer fichier',
	'S_IMPORT'=>			'Importer',
	'S_IMPORT_BIG'=>			'IMPORTER',
	'S_IMPORT_HOSTS'=>			'Importer hotes',
	'S_IMPORT_HOSTS_BIG'=>			'IMPORTER HOTES',
	'S_EXPORT'=>			'Exporter',
	'S_EXPORT_FILE'=>			'Exporter fichier',
	'S_EXPORT_BIG'=>			'EXPORTER',
	'S_PREVIEW'=>			'Aperçu',
	'S_BACK'=>			'Retour',
	'S_NO_DATA_FOR_EXPORT'=>			'Aucune donnée à exporter',
	'S_RULES'=>			'Règles',
	'S_SKIP'=>			'Sauter',
	'S_EXISTING'=>			'Existant',
	'S_MISSING'=>			'Omis',
	'S_REFRESH'=>			'Rafraichir',
	'S_PREVIOUS'=>			'Précédent',
	'S_NEXT'=>			'Suivant',
	'S_RETRY'=>			'Réessayer',
	'S_FINISH'=>			'Termin',
	'S_FAIL'=>			'Echec',
	'S_UPDATE_BIG'=>			'MODIF',
	'S_INSTALLATION'=>			'Installation',
	'S_NEW_INSTALLATION'=>			'Nouvelle installation',
	'S_NEW_INSTALLATION_BIG'=>			'NOUVELLE INSTALLATION',
	'S_INSTALLATION_UPDATE'=>			'Installation/Modif',
	'S_TIME_ZONE'=>			'Time zone',
	'S_DO_NOT_KEEP_HISTORY_OLDER_THAN'=>			'Ne pas conserver l\'historique de plus de (in days)',
	'S_DO_NOT_KEEP_TRENDS_OLDER_THAN'=>			'Ne pas conserver les tendances de plus de (in days)',
	'S_MASTER_NODE'=>			'Noeud maitre',
	'S_REMOTE'=>			'Distant',
	'S_MASTER'=>			'Maitre',
	'S_NODE_UPDATED'=>			'Noeud modifi',
	'S_CANNOT_UPDATE_NODE'=>			'Modification noeud impossible',
	'S_NODE_ADDED'=>			'Noeud ajout',
	'S_CANNOT_ADD_NODE'=>			'Ajout noeud impossible',
	'S_NODE_DELETED'=>			'Noeud supprim',
	'S_CANNOT_DELETE_NODE'=>			'Suppression neud impossible',
	'S_CURRENT_NODE'=>			'Noeud courant',
	'S_ACKNOWLEDGES'=>			'Acquittements',
	'S_ACKNOWLEDGE'=>			'Acquittement',
	'S_ACKNOWLEDGE_ALARM_BY'=>			'Acquittement alarme par',
	'S_ADD_COMMENT_BY'=>			'Ajout commentaire par',
	'S_COMMENT_ADDED'=>			'Commentaire ajout',
	'S_CANNOT_ADD_COMMENT'=>			'Ajout commentaire impossible',
	'S_ALARM_ACKNOWLEDGES_BIG'=>			'ACQUITTEMENT ALARME',
	'S_ACKNOWLEDGE_ADDED'=>			'Acquittement ajout',
	'S_CONFIGURATION_OF_ACTIONS'=>			'Configuration des actions',
	'S_CONFIGURATION_OF_ACTIONS_BIG'=>			'CONFIGURATION DES ACTIONS',
	'S_FILTER_HOST_GROUP'=>			'Filtre: Group hote',
	'S_FILTER_HOST'=>			'Filtre: Hote',
	'S_FILTER_TRIGGER'=>			'Filtre: Déclencheur',
	'S_FILTER_TRIGGER_NAME'=>			'Filtre: Nom déclencheur',
	'S_FILTER_TRIGGER_SEVERITY'=>			'Filtre: Criticité déclencheur',
	'S_FILTER_WHEN_TRIGGER_BECOMES'=>			'Filtre: Quand le déclencheur passe à',
	'S_OPERATION_TYPE'=>			'Type d\'opération',
	'S_SEND_MESSAGE'=>			'Envoi message',
	'S_REMOTE_COMMAND'=>			'Commande Remote',
	'S_REMOTE_COMMANDS'=>			'Commandes Remote',
	'S_FILTER'=>			'Filtre',
	'S_FILTER_TYPE'=>			'Type de filtre',
	'S_TRIGGER_NAME'=>			'Nom déclencheur',
	'S_TRIGGER_SEVERITY'=>			'Criticité déclencheur',
	'S_TRIGGER_VALUE'=>			'Valeur déclencheur',
	'S_TIME_PERIOD'=>			'Période de temps',
	'S_TRIGGER_DESCRIPTION'=>			'Description déclencheur',
	'S_CONDITIONS'=>			'Conditions',
	'S_CONDITION'=>			'Condition',
	'S_NEW_CONDITION'=>			'Nouvelle condition',
	'S_OPERATIONS'=>			'Operations',
	'S_OPERATION'=>			'Operation',
	'S_NEW_OPERATION'=>			'Nouvelle operation',
	'S_EDIT_OPERATION'=>			'Editer operation',
	'S_NO_CONDITIONS_DEFINED'=>			'Aucune condition définie',
	'S_ACTIONS_DELETED'=>			'Actions supprimées',
	'S_CANNOT_DELETE_ACTIONS'=>			'Suppression actions impossible',
	'S_NO_OPERATIONS_DEFINED'=>			'Aucune opération définie',
	'S_NEW'=>			'Nouveau',
	'S_ADD_HOST'=>			'Ajouter hote',
	'S_REMOVE_HOST'=>			'Supprimer hote',
	'S_LINK_TO_TEMPLATE'=>			'Lier au modèle',
	'S_UNLINK_FROM_TEMPLATE'=>			'Supprimer lien au modèle',
	'S_INCORRECT_TRIGGER'=>			'Déclencheur incorrect',
	'S_INCORRECT_HOST'=>			'Hote incorrect',
	'S_INCORRECT_PERIOD'=>			'Période incorrecte',
	'S_INCORRECT_IP'=>			'IP incorrecte',
	'S_INCORRECT_DISCOVERY_CHECK'=>			'Vérification découverte incorrecte',
	'S_INCORRECT_PORT'=>			'Port incorrect',
	'S_INCORRECT_DISCOVERY_STATUS'=>			'Statut découverte incorrect',
	'S_INCORRECT_CONDITION_TYPE'=>			'Type de condition incorrecte',
	'S_INCORRECT_OPERATION_TYPE'=>			'Type d\'opération incorrecte',
	'S_INCORRECT_USER'=>			'Utilisateur incorrect',
	'S_ACTIONS'=>			'Actions',
	'S_ACTION_ADDED'=>			'Action ajoutée',
	'S_CANNOT_ADD_ACTION'=>			'Impossible d\'ajouter l\'action',
	'S_ACTION_UPDATED'=>			'Action mise à jour',
	'S_CANNOT_UPDATE_ACTION'=>			'Impossible de mettre à jour l\'action',
	'S_ACTION_DELETED'=>			'Action supprimée',
	'S_CANNOT_DELETE_ACTION'=>			'Impossible de supprimer l\'action',
	'S_SCOPE'=>			'Étendue',
	'S_SEND_MESSAGE_TO'=>			'Envoyer le message',
	'S_RUN_REMOTE_COMMANDS'=>			'Lancement remote command',
	'S_WHEN_TRIGGER'=>			'Lorsque déclencheur',
	'S_DELAY'=>			'Délai',
	'S_SUBJECT'=>			'Sujet',
	'S_ON'=>			'OUVERT',
	'S_OFF'=>			'FERM',
	'S_NO_ACTIONS_DEFINED'=>			'Aucune action définie',
	'S_SINGLE_USER'=>			'Simple utilisateur',
	'S_USER_GROUP'=>			'Groupe d\'utilisateurs',
	'S_GROUP'=>			'Groupe',
	'S_USER'=>			'Utilisateur',
	'S_ON_OR_OFF'=>			'OUVERT ou FERM',
	'S_DELAY_BETWEEN_MESSAGES_IN_SEC'=>			'Délai entre messages (en sec)',
	'S_DELAY_BETWEEN_EXECUTIONS_IN_SEC'=>			'Délai entre exécuation (en sec)',
	'S_MESSAGE'=>			'Message',
	'S_THIS_TRIGGER_ONLY'=>			'Ce déclencheur seulement',
	'S_ALL_TRIGGERS_OF_THIS_HOST'=>			'Tous les déclencheurs pour cet hôte',
	'S_ALL_TRIGGERS'=>			'Tous les déclencheurs',
	'S_USE_IF_TRIGGER_SEVERITY'=>			'Utiliser si la sévérité du déclencheur est supérieure ou égale à',
	'S_NOT_CLASSIFIED'=>			'Non class',
	'S_INFORMATION'=>			'Information',
	'S_WARNING'=>			'Avertissement',
	'S_AVERAGE'=>			'Moyen',
	'S_HIGH'=>			'Haut',
	'S_DISASTER'=>			'Désastre',
	'S_AND_OR_BIG'=>			'ET / OU',
	'S_AND_BIG'=>			'ET',
	'S_AND'=>			'et',
	'S_OR_BIG'=>			'OU',
	'S_OR'=>			'ou',
	'S_TYPE_OF_CALCULATION'=>			'Type de calcul',
	'S_CREATE_ACTION'=>			'Créer une action',
	'S_ENABLE_SELECTED_ACTIONS_Q'=>			'Activer les actions sléectionnées?',
	'S_DISABLE_SELECTED_ACTIONS_Q'=>			'Désactiver les actions sélectionnées?',
	'S_DELETE_SELECTED_ACTION_Q'=>			'Supprimer les actions sélectionnées?',
	'S_ALARMS'=>			'Alertes',
	'S_ALARMS_SMALL'=>			'Alertes',
	'S_ALARMS_BIG'=>			'ALERTES',
	'S_SHOW_ONLY_LAST_100'=>			'Afficher seulement les 100 derniers',
	'S_SHOW_ALL'=>			'Afficher tout',
	'S_TIME'=>			'Heure',
	'S_STATUS'=>			'Statut',
	'S_DURATION'=>			'Durée',
	'S_SUM'=>			'Somme',
	'S_TRUE_BIG'=>			'VRAI',
	'S_FALSE_BIG'=>			'FAUX',
	'S_DISABLED_BIG'=>			'DÉSACTIVÉ',
	'S_UNKNOWN_BIG'=>			'INCONNU',
	'S_HISTORY_OF_ACTIONS_BIG'=>			'HISTORIQUE DES ACTIONS',
	'S_LATEST_ACTIONS'=>			'Dernières actions',
	'S_ALERTS_BIG'=>			'ALERTES',
	'S_TYPE'=>			'Type',
	'S_RECIPIENTS'=>			'Destinataire(s)',
	'S_ERROR'=>			'Erreur',
	'S_SENT'=>			'envoy',
	'S_NOT_SENT'=>			'non envoy',
	'S_NO_ACTIONS_FOUND'=>			'Aucune action trouvée',
	'S_SHOW_NEXT_100'=>			'Afficher les 100 prochains',
	'S_SHOW_PREVIOUS_100'=>			'Afficher les 100 précédents',
	'S_CUSTOM_GRAPHS'=>			'Graphiques personnalisés',
	'S_GRAPHS_BIG'=>			'GRAPHIQUES',
	'S_NO_GRAPHS_TO_DISPLAY'=>			'Aucun graphique n\'est affichable',
	'S_SELECT_GRAPH_TO_DISPLAY'=>			'Sélectionnez le graphique à afficher',
	'S_PERIOD'=>			'Période',
	'S_1H'=>			'1h',
	'S_2H'=>			'2h',
	'S_4H'=>			'4h',
	'S_8H'=>			'8h',
	'S_12H'=>			'12h',
	'S_24H'=>			'24h',
	'S_WEEK_SMALL'=>			'semaine',
	'S_MONTH_SMALL'=>			'mois',
	'S_YEAR_SMALL'=>			'année',
	'S_KEEP_PERIOD'=>			'Conserver la période',
	'S_ON_C'=>			'Ouvert',
	'S_OFF_C'=>			'Ferm',
	'S_MOVE'=>			'Déplacer',
	'S_NAVIGATE'=>			'Naviguer',
	'S_INCREASE'=>			'Incrémenter',
	'S_DECREASE'=>			'Décrémenter',
	'S_RIGHT_DIR'=>			'Droite',
	'S_LEFT_DIR'=>			'Gauche',
	'S_SELECT_GRAPH_DOT_DOT_DOT'=>			'Sélectionnez le graphique...',
	'S_BLACK'=>			'Noir',
	'S_BLUE'=>			'Bleu',
	'S_CYAN'=>			'Cyan',
	'S_DARK_BLUE'=>			'Bleu fonc',
	'S_DARK_GREEN'=>			'Vert fonc',
	'S_DARK_RED'=>			'Rouge fonc',
	'S_DARK_YELLOW'=>			'Jaune fonc',
	'S_GREEN'=>			'Vert',
	'S_RED'=>			'Rouge',
	'S_WHITE'=>			'Blanc',
	'S_YELLOW'=>			'Jaune',
	'S_CANNNOT_UPDATE_VALUE_MAP'=>			'Modification valeur carte impossible',
	'S_VALUE_MAP_ADDED'=>			'Valeur de carte ajoutée',
	'S_CANNNOT_ADD_VALUE_MAP'=>			'Ajout valeur de carte impossible',
	'S_VALUE_MAP_DELETED'=>			'Valeur de carte supprimée',
	'S_CANNNOT_DELETE_VALUE_MAP'=>			'Suppression valeur de carte impossible',
	'S_VALUE_MAP_UPDATED'=>			'Valeur de carte modifiée',
	'S_VALUE_MAPPING_BIG'=>			'VALEUR DE CARTE',
	'S_VALUE_MAPPING'=>			'Valeur de carte',
	'S_VALUE_MAP'=>			'Valeur de carte',
	'S_MAPPING'=>			'Cartographie',
	'S_NEW_MAPPING'=>			'Nouvelle carte',
	'S_NO_MAPPING_DEFINED'=>			'Aucune carte définie',
	'S_CREATE_VALUE_MAP'=>			'Créer valeur de carte',
	'S_CONFIGURATION_OF_ZABBIX'=>			'Configuration de Zabbix',
	'S_CONFIGURATION_OF_ZABBIX_BIG'=>			'CONFIGURATION DE ZABBIX',
	'S_CONFIGURATION_UPDATED'=>			'Configuration actualisée',
	'S_CONFIGURATION_WAS_NOT_UPDATED'=>			'Configuration non actualisée',
	'S_ADDED_NEW_MEDIA_TYPE'=>			'Nouveau type de média ajouté',
	'S_NEW_MEDIA_TYPE_WAS_NOT_ADDED'=>			'Nouveau type de média non ajouté',
	'S_MEDIA_TYPE_UPDATED'=>			'Type de média actualisé',
	'S_MEDIA_TYPE_WAS_NOT_UPDATED'=>			'Type média non actualisé',
	'S_MEDIA_TYPE_DELETED'=>			'Type média supprimé',
	'S_MEDIA_TYPE_WAS_NOT_DELETED'=>			'Type de média non supprimé',
	'S_CONFIGURATION'=>			'Configuration',
	'S_ADMINISTRATION'=>			'Administration',
	'S_DO_NOT_KEEP_ACTIONS_OLDER_THAN'=>			'Ne pas conserver les actions plus anciennes que (jours)',
	'S_DO_NOT_KEEP_EVENTS_OLDER_THAN'=>			'Ne pas conserver événements plus anciens que (jours)',
	'S_NO_MEDIA_TYPES_DEFINED'=>			'Aucun type média défini',
	'S_SMTP_SERVER'=>			'serveur SMTP',
	'S_SMTP_HELO'=>			'SMTP HELO',
	'S_SMTP_EMAIL'=>			'Courriel SMTP',
	'S_SCRIPT_NAME'=>			'Nom script',
	'S_DELETE_SELECTED_MEDIA'=>			'Supprimer média sélectionné?',
	'S_DELETE_SELECTED_IMAGE'=>			'Supprimer image sélectionnée?',
	'S_HOUSEKEEPER'=>			'Conservation informations',
	'S_MEDIA_TYPES'=>			'Types média',
	'S_ESCALATION_RULES'=>			'Règles d\'escalade',
	'S_ESCALATION'=>			'Escalade',
	'S_ESCALATION_RULES_BIG'=>			'RÈGLES D\'ESCALADE',
	'S_NO_ESCALATION_RULES_DEFINED'=>			'Aucune règle d\'escalade définie',
	'S_NO_ESCALATION_DETAILS'=>			'Pas de détails pour escalade',
	'S_ESCALATION_DETAILS_BIG'=>			'DÉTAILS ESCALADE',
	'S_ESCALATION_ADDED'=>			'Escalade ajoutée',
	'S_ESCALATION_WAS_NOT_ADDED'=>			'Impossible d\'ajouter l\'escalade',
	'S_ESCALATION_RULE_ADDED'=>			'Règle d\'escalade ajoutée',
	'S_ESCALATION_RULE_WAS_NOT_ADDED'=>			'Règle d\'escalade non ajoutée',
	'S_ESCALATION_RULE_UPDATED'=>			'Règle d\'escalade actualisée',
	'S_ESCALATION_RULE_WAS_NOT_UPDATED'=>			'Règle d\'escalade non actualisée',
	'S_ESCALATION_RULE_DELETED'=>			'Règle d\'escalade supprimée',
	'S_ESCALATION_RULE_WAS_NOT_DELETED'=>			'Règle d\'escalade non supprimée',
	'S_ESCALATION_UPDATED'=>			'Escalade actualisée',
	'S_ESCALATION_WAS_NOT_UPDATED'=>			'Escalade non actualisée',
	'S_ESCALATION_DELETED'=>			'Escalade supprimée',
	'S_ESCALATION_WAS_NOT_DELETED'=>			'Escalade non supprimée',
	'S_ESCALATION_RULE'=>			'Règle d\'escalade',
	'S_DO'=>			'Faire',
	'S_DEFAULT'=>			'Défaut',
	'S_IS_DEFAULT'=>			'Est en défaut',
	'S_LEVEL'=>			'Niveau',
	'S_DELAY_BEFORE_ACTION'=>			'Délai avant action',
	'S_IMAGES'=>			'Images',
	'S_IMAGE'=>			'Image',
	'S_IMAGES_BIG'=>			'IMAGES',
	'S_ICON'=>			'Icône',
	'S_NO_IMAGES_DEFINED'=>			'Aucune image n\'est définie',
	'S_BACKGROUND'=>			'Fond',
	'S_UPLOAD'=>			'Télécharger',
	'S_IMAGE_ADDED'=>			'Image ajoutée',
	'S_CANNOT_ADD_IMAGE'=>			'Impossible d\'ajouter l\'image',
	'S_IMAGE_DELETED'=>			'Image supprimée',
	'S_CANNOT_DELETE_IMAGE'=>			'Impossible de supprimer l\'image',
	'S_IMAGE_UPDATED'=>			'Image modifiée',
	'S_CANNOT_UPDATE_IMAGE'=>			'Impossible de modifier l\'image',
	'S_UPDATE_SELECTED_IMAGE'=>			'Modifier l\'image?',
	'S_PRIORITY'=>			'Priorit',
	'S_PATTERN'=>			'Remplissage',
	'S_OTHER'=>			'Autre',
	'S_OTHER_PARAMETERS'=>			'Autres paramètres',
	'S_REFRESH_UNSUPPORTED_ITEMS'=>			'Rafraichissement des items non supportés (in sec)',
	'S_CREATE_MEDIA_TYPE'=>			'Créer type de média',
	'S_CREATE_IMAGE'=>			'Créer image',
	'S_WORKING_TIME'=>			'Temps de travail',
	'S_USER_GROUP_FOR_DATABASE_DOWN_MESSAGE'=>			'User group for database down message',
	'S_INCORRECT_GROUP'=>			'Groupe incorrect',
	'S_NOTHING_TO_DO'=>			'Rien à faire',
	'S_ICORRECT_WORK_PERIOD'=>			'Période travail incorrecte',
	'S_NODE'=>			'Noeud',
	'S_NODES'=>			'Noeuds',
	'S_NODES_BIG'=>			'NOEUDS',
	'S_NEW_NODE'=>			'Nouveau noeud',
	'S_NO_NODES_DEFINED'=>			'Aucun noeud défini',
	'S_LATEST_VALUES'=>			'Dernières données',
	'S_NO_PERMISSIONS'=>			'Pas de permissions !',
	'S_LATEST_DATA_BIG'=>			'DERNIERES DONNEES',
	'S_ALL_SMALL'=>			'tout',
	'S_MINUS_ALL_MINUS'=>			'- tous -',
	'S_MINUS_OTHER_MINUS'=>			'- autre -',
	'S_DESCRIPTION_LARGE'=>			'DESCRIPTION',
	'S_DESCRIPTION_SMALL'=>			'Description',
	'S_GRAPH'=>			'Graphique',
	'S_TREND'=>			'Tendance',
	'S_COMPARE'=>			'Comparaison',
	'S_COPYRIGHT_BY'=>			'Copyright 2001-2006 par',
	'S_CONNECTED_AS'=>			'Connecté au nom de',
	'S_SIA_ZABBIX'=>			'SIA Zabbix',
	'S_CONFIGURATION_OF_GRAPH'=>			'Configuration du graphique',
	'S_CONFIGURATION_OF_GRAPH_BIG'=>			'CONFIGURATION DU GRAPHIQUE',
	'S_ITEM_ADDED'=>			'Item ajout',
	'S_ITEM_UPDATED'=>			'Item actualis',
	'S_ITEMS_UPDATED'=>			'Items modifiés',
	'S_SORT_ORDER_UPDATED'=>			'Ordre du tri actualis',
	'S_CANNOT_UPDATE_SORT_ORDER'=>			'Impossible d\'actualiser ordre du tri',
	'S_DISPLAYED_PARAMETERS_BIG'=>			'PARAMÈTRES AFFICHÉS',
	'S_SORT_ORDER'=>			'Ordre du tri',
	'S_PARAMETER'=>			'Paramètre',
	'S_COLOR'=>			'Couleur',
	'S_UP'=>			'Haut',
	'S_DOWN'=>			'Bas',
	'S_NEW_ITEM_FOR_THE_GRAPH'=>			'Nouvel item pour le graphique',
	'S_SORT_ORDER_1_100'=>			'Ordre du tri (0->100)',
	'S_YAXIS_SIDE'=>			'Coté axe des Y',
	'S_LEFT'=>			'Gauche',
	'S_FUNCTION'=>			'Fonction',
	'S_MIN_SMALL'=>			'min',
	'S_AVG_SMALL'=>			'moy',
	'S_MAX_SMALL'=>			'max',
	'S_DRAW_STYLE'=>			'Style de dessin',
	'S_SIMPLE'=>			'Simple',
	'S_GRAPH_TYPE'=>			'Type de graphe',
	'S_STACKED'=>			'Empil',
	'S_NORMAL'=>			'Normal',
	'S_AGGREGATED'=>			'Agrégé',
	'S_AGGREGATED_PERIODS_COUNT'=>			'Compte des périodes agrégées',
	'S_CONFIGURATION_OF_GRAPHS'=>			'Configuration des graphiques',
	'S_CONFIGURATION_OF_GRAPHS_BIG'=>			'CONFIGURATION DES GRAPHIQUES',
	'S_GRAPH_ADDED'=>			'Graphique ajout',
	'S_GRAPH_UPDATED'=>			'Graphique actualis',
	'S_CANNOT_UPDATE_GRAPH'=>			'Impossible d\'actualiser le graphique',
	'S_GRAPH_DELETED'=>			'Graphique supprim',
	'S_CANNOT_DELETE_GRAPH'=>			'Impossible de supprimer le graphique',
	'S_CANNOT_ADD_GRAPH'=>			'Impossible d\'ajouter le graphique',
	'S_ID'=>			'Id',
	'S_NO_GRAPHS_DEFINED'=>			'Aucun graphique n\'est défini',
	'S_DELETE_GRAPH_Q'=>			'Supprimer le graphique?',
	'S_YAXIS_TYPE'=>			'Type axe Y',
	'S_YAXIS_MIN_VALUE'=>			'Valeur MIN axe Y',
	'S_YAXIS_MAX_VALUE'=>			'Valeur MAX axe Y',
	'S_CALCULATED'=>			'Calcul',
	'S_FIXED'=>			'Fixe',
	'S_CREATE_GRAPH'=>			'Création graphe',
	'S_SHOW_WORKING_TIME'=>			'Montrer temps de travail',
	'S_SHOW_TRIGGERS'=>			'Montrer les déclencheurs',
	'S_GRAPH_ITEM'=>			'Graphe des items',
	'S_REQUIRED_ITEMS_FOR_GRAPH'=>			'Items requis pour le graphe',
	'S_LAST_HOUR_GRAPH'=>			'Graphique dernière heure',
	'S_LAST_WEEK_GRAPH'=>			'Graphe dernière semaine',
	'S_LAST_MONTH_GRAPH'=>			'Graphe dernier mois',
	'S_VALUES_OF_LAST_HOUR'=>			'Valeurs dernière heure',
	'S_500_LATEST_VALUES'=>			'500 dernières valeurs',
	'S_GRAPH_OF_SPECIFIED_PERIOD'=>			'Graphe pour la période précisée',
	'S_VALUES_OF_SPECIFIED_PERIOD'=>			'Valeurs période spécifique',
	'S_VALUES_IN_PLAIN_TEXT_FORMAT'=>			'Valeurs en format texte brut',
	'S_TIMESTAMP'=>			'Horodateur',
	'S_LOCAL'=>			'Local',
	'S_SOURCE'=>			'Source',
	'S_SHOW_SELECTED'=>			'Montrer sélections',
	'S_HIDE_SELECTED'=>			'Cacher sélections',
	'S_MARK_SELECTED'=>			'Marquer les éléments sélectionnés',
	'S_MARK_OTHERS'=>			'Marquer les autres',
	'S_AS_RED'=>			'en Rouge',
	'S_AS_GREEN'=>			'en Vert',
	'S_AS_BLUE'=>			'en Bleu',
	'S_APPLICATION'=>			'Application',
	'S_APPLICATIONS'=>			'Applications',
	'S_APPLICATIONS_BIG'=>			'APPLICATIONS',
	'S_CREATE_APPLICATION'=>			'Créer application',
	'S_DELETE_SELECTED_APPLICATIONS_Q'=>			'Supprimer les applications sélectionnées?',
	'S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Désactiver les items des applications sélectionnées?',
	'S_ACTIVATE_ITEMS'=>			'Activer les Items',
	'S_DISABLE_ITEMS'=>			'Désactiver les  Items',
	'S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q'=>			'Activer les items des applications sélectionnées?',
	'S_APPLICATION_UPDATED'=>			'Application modifiée',
	'S_CANNOT_UPDATE_APPLICATION'=>			'Modification application impossible',
	'S_APPLICATION_ADDED'=>			'Application ajoutée',
	'S_CANNOT_ADD_APPLICATION'=>			'Ajout application impossible',
	'S_APPLICATION_DELETED'=>			'Application supprimée',
	'S_CANNOT_DELETE_APPLICATION'=>			'Suppression application impossible',
	'S_NO_APPLICATIONS_DEFINED'=>			'Aucune application définie',
	'S_HOSTS'=>			'Hotes',
	'S_ITEMS'=>			'Items',
	'S_ITEMS_BIG'=>			'ITEMS',
	'S_TRIGGERS'=>			'Déclencheurs',
	'S_GRAPHS'=>			'Graphiques',
	'S_HOST_ADDED'=>			'Hôte ajouté',
	'S_CANNOT_ADD_HOST'=>			'Impossible d\'ajouter l\'hôte',
	'S_ITEMS_ADDED'=>			'Items ajoutés',
	'S_CANNOT_ADD_ITEMS'=>			'Impossible d\'ajouter les items',
	'S_HOST_UPDATED'=>			'Hôte actualisé',
	'S_CANNOT_UPDATE_HOST'=>			'Impossible d\'actualiser l\'hôte',
	'S_HOST_STATUS_UPDATED'=>			'Statut hôte actualisé',
	'S_CANNOT_UPDATE_HOST_STATUS'=>			'Impossible d\'actualiser le statut de l\'hôte',
	'S_HOST_DELETED'=>			'Hôte supprimé',
	'S_CANNOT_DELETE_HOST'=>			'Impossible de supprimer l\'hôte',
	'S_TEMPLATE_LINKAGE_ADDED'=>			'Lien avec modèle ajouté',
	'S_CANNOT_ADD_TEMPLATE_LINKAGE'=>			'Impossible d\'ajouter lien avec le modèle',
	'S_TEMPLATE_LINKAGE_UPDATED'=>			'Lien avec modèle actualisé',
	'S_CANNOT_UPDATE_TEMPLATE_LINKAGE'=>			'Impossible d\'actualiser le lien avec le modèle',
	'S_TEMPLATE_LINKAGE_DELETED'=>			'Lien avec modèle supprimé',
	'S_CANNOT_DELETE_TEMPLATE_LINKAGE'=>			'Impossible de supprimer le lien avec le modèle',
	'S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES'=>			'CONFIGURATION DES HOTES, GROUPS ET MODELES',
	'S_HOST_GROUPS_BIG'=>			'GROUPES D\'HÔTES',
	'S_START'=>			'Démarrer',
	'S_STOP'=>			'Arreter',
	'S_NO_HOST_GROUPS_DEFINED'=>			'Aucun groupe d\'hôtes n\'est défini',
	'S_NO_LINKAGES_DEFINED'=>			'Aucun lien n\'est défini',
	'S_NO_HOSTS_DEFINED'=>			'Aucun hôte n\'est défini',
	'S_NO_TEMPLATES_DEFINED'=>			'Aucun modèle défini',
	'S_HOSTS_BIG'=>			'HÔTES',
	'S_HOST'=>			'Hôte',
	'S_HOST_BIG'=>			'HOTE',
	'S_CONNECT_TO'=>			'Connexion',
	'S_DNS'=>			'DNS',
	'S_IP'=>			'IP',
	'S_PORT'=>			'Port',
	'S_MONITORED'=>			'Surveill',
	'S_NOT_MONITORED'=>			'Non surveill',
	'S_UNREACHABLE'=>			'Non joignable',
	'S_TEMPLATE'=>			'Modèle',
	'S_TEMPLATE_SMALL'=>			'modèle',
	'S_DELETED'=>			'Supprim',
	'S_UNKNOWN'=>			'Inconnu',
	'S_GROUPS'=>			'Groupes',
	'S_NO_GROUPS_DEFINED'=>			'Aucun groupe défini',
	'S_NEW_GROUP'=>			'Nouveau groupe',
	'S_DNS_NAME'=>			'Nom DNS',
	'S_IP_ADDRESS'=>			'adresse IP',
	'S_LINK_WITH_TEMPLATE'=>			'Lien avec le modèle',
	'S_USE_PROFILE'=>			'Utilisation profil',
	'S_DELETE_SELECTED_HOST_Q'=>			'Supprimer hôte sélectionné?',
	'S_DELETE_SELECTED_GROUP_Q'=>			'Supprimer le groupe sélectionné?',
	'S_DELETE_SELECTED_GROUPS_Q'=>			'Supprimer les groupes sélectionnés?',
	'S_DELETE_SELECTED_WITH_LINKED_ELEMENTS'=>			'Supprimer les liens avec les éléments sélectionnés',
	'S_GROUP_NAME'=>			'Nom groupe',
	'S_HOST_GROUP'=>			'Groupe d\'hôte',
	'S_HOST_GROUPS'=>			'Groupes d\'hôtes',
	'S_UPDATE'=>			'Actualiser',
	'S_AVAILABILITY'=>			'Disponibilité',
	'S_AVAILABLE'=>			'Disponible',
	'S_NOT_AVAILABLE'=>			'Non disponible',
	'S_HOST_PROFILE'=>			'Profil hote',
	'S_DEVICE_TYPE'=>			'Type périphérique',
	'S_OS'=>			'OS',
	'S_SERIALNO'=>			'Numéro de série',
	'S_TAG'=>			'Marque',
	'S_HARDWARE'=>			'Matériel',
	'S_SOFTWARE'=>			'Logiciel',
	'S_CONTACT'=>			'Contact',
	'S_LOCATION'=>			'Situation',
	'S_NOTES'=>			'Notes',
	'S_MACADDRESS'=>			'Addresse MAC',
	'S_PROFILE_ADDED'=>			'Profil ajout',
	'S_CANNOT_ADD_PROFILE'=>			'Ajout profil impossible',
	'S_PROFILE_UPDATED'=>			'Profil modifi',
	'S_CANNOT_UPDATE_PROFILE'=>			'Modification profil impossible',
	'S_PROFILE_DELETED'=>			'Profil supprim',
	'S_CANNOT_DELETE_PROFILE'=>			'Suppression profil impossible',
	'S_ADD_TO_GROUP'=>			'Ajouter au groupe',
	'S_DELETE_FROM_GROUP'=>			'Supprimer du groupe',
	'S_UPDATE_IN_GROUP'=>			'Modifier dans le groupe',
	'S_DELETE_SELECTED_HOSTS_Q'=>			'Suppresion des hotes sélectionnés?',
	'S_DISABLE_SELECTED_HOSTS_Q'=>			'Désactivation des hotes sélectionnés?',
	'S_ACTIVATE_SELECTED_HOSTS_Q'=>			'Activation des hotes sélectionnés?',
	'S_SELECT_HOST_TEMPLATE_FIRST'=>			'Sélectionnez ler modèle d\'hote en premier',
	'S_CREATE_HOST'=>			'Créer hote',
	'S_CREATE_TEMPLATE'=>			'Créer modèle',
	'S_TEMPLATE_LINKAGE'=>			'Lien modèle',
	'S_TEMPLATE_LINKAGE_BIG'=>			'LIEN MODELE',
	'S_NO_LINKAGES'=>			'Aucun lien',
	'S_TEMPLATES'=>			'Modèles',
	'S_TEMPLATES_BIG'=>			'MODELES',
	'S_UNLINK'=>			'Supprimer lien',
	'S_UNLINK_AND_CLEAR'=>			'Supprimer lien et nettoyer',
	'S_UNLINKED_SMALL'=>			'Lien supprim',
	'S_CLEANED_SMALL'=>			'nettoy',
	'S_NO_ITEMS_DEFINED'=>			'Aucun item défini',
	'S_HISTORY_CLEANED'=>			'Historique nettoy',
	'S_CLEAN_HISTORY_SELECTED_ITEMS'=>			'Nettoyage historique des items sélectionnés',
	'S_CLEAN_HISTORY'=>			'Nettoiyage historique',
	'S_CANNOT_CLEAN_HISTORY'=>			'Nettoyage historique impossible',
	'S_CONFIGURATION_OF_ITEMS'=>			'Configuration des items',
	'S_CONFIGURATION_OF_ITEMS_BIG'=>			'CONFIGURATION DES ITEMS',
	'S_CANNOT_UPDATE_ITEM'=>			'Impossible d\'actualiser l\'item',
	'S_STATUS_UPDATED'=>			'Statut actualis',
	'S_CANNOT_UPDATE_STATUS'=>			'Impossible d\'actualiser le statut',
	'S_CANNOT_ADD_ITEM'=>			'Impossible d\'ajouter l\'item',
	'S_ITEM_DELETED'=>			'Item supprim',
	'S_CANNOT_DELETE_ITEM'=>			'Impossible de supprimer l\'item',
	'S_ITEMS_DELETED'=>			'Items supprimés',
	'S_CANNOT_DELETE_ITEMS'=>			'Impossible de supprimer les items',
	'S_ITEMS_ACTIVATED'=>			'Items activés',
	'S_CANNOT_ACTIVATE_ITEMS'=>			'Impossible d\'activer les items',
	'S_ITEMS_DISABLED'=>			'Items désactivés',
	'S_CANNOT_DISABLE_ITEMS'=>			'Désactivation items impossible',
	'S_SERVERNAME'=>			'Nom du serveur',
	'S_KEY'=>			'Cl',
	'S_DESCRIPTION'=>			'Description',
	'S_UPDATE_INTERVAL'=>			'Intervalle d\'actualisation',
	'S_HISTORY'=>			'Historique',
	'S_TRENDS'=>			'Tendances',
	'S_SHORT_NAME'=>			'Nom court',
	'S_ZABBIX_AGENT'=>			'agent ZABBIX',
	'S_ZABBIX_AGENT_ACTIVE'=>			'agent D3YSTEM (actif)',
	'S_SNMPV1_AGENT'=>			'agent SNMPv1',
	'S_ZABBIX_TRAPPER'=>			'ZABBIX trapper',
	'S_SIMPLE_CHECK'=>			'Vérification simple',
	'S_SNMPV2_AGENT'=>			'agent SNMPv2',
	'S_SNMPV3_AGENT'=>			'agent SNMPv3',
	'S_ZABBIX_INTERNAL'=>			'ZABBIX interne',
	'S_ZABBIX_AGGREGATE'=>			'Aggrégation Zabbix',
	'S_EXTERNAL_CHECK'=>			'Vérification externe',
	'S_WEB_MONITORING'=>			'Supervision Web',
	'S_ZABBIX_UNKNOWN'=>			'Inconnu',
	'S_ACTIVE'=>			'Actif',
	'S_NOT_ACTIVE'=>			'Inactif',
	'S_NOT_SUPPORTED'=>			'Non support',
	'S_ACTIVATE_SELECTED_ITEMS_Q'=>			'Activer items sélectionnés?',
	'S_DISABLE_SELECTED_ITEMS_Q'=>			'Désactiver items sélectionnés?',
	'S_DELETE_SELECTED_ITEMS_Q'=>			'Supprimer items sélectionnés?',
	'S_EMAIL'=>			'Courriel',
	'S_JABBER'=>			'Messagerie Jabber',
	'S_JABBER_IDENTIFIER'=>			'Identifiant Jabber',
	'S_SMS'=>			'SMS',
	'S_SCRIPT'=>			'Script',
	'S_GSM_MODEM'=>			'Modem GSM',
	'S_UNITS'=>			'Unités',
	'S_MULTIPLIER'=>			'Multiplicateur',
	'S_UPDATE_INTERVAL_IN_SEC'=>			'Intervalle d\'actualisation (en sec)',
	'S_KEEP_HISTORY_IN_DAYS'=>			'Conserver historique (en jours)',
	'S_KEEP_TRENDS_IN_DAYS'=>			'Conserver tendances (en jours)',
	'S_TYPE_OF_INFORMATION'=>			'Type d\'information',
	'S_STORE_VALUE'=>			'Stocker valeur',
	'S_SHOW_VALUE'=>			'Montrer valeur',
	'S_NUMERIC_UNSIGNED'=>			'Numérique (integer 64bit)',
	'S_NUMERIC_FLOAT'=>			'Numérique (float)',
	'S_CHARACTER'=>			'Caractère',
	'S_LOG'=>			'Journal',
	'S_TEXT'=>			'Texte',
	'S_AS_IS'=>			'Tel quel',
	'S_DELTA_SPEED_PER_SECOND'=>			'Delta (vitesse par seconde)',
	'S_DELTA_SIMPLE_CHANGE'=>			'Delta (changement simple)',
	'S_ITEM'=>			'Item',
	'S_SNMP_COMMUNITY'=>			'Communauté SNMP',
	'S_SNMP_OID'=>			'OID SNMP',
	'S_SNMP_PORT'=>			'port SNMP',
	'S_ALLOWED_HOSTS'=>			'Hôtes autorisés',
	'S_SNMPV3_SECURITY_NAME'=>			'Nom sécurité SNMPv3',
	'S_SNMPV3_SECURITY_LEVEL'=>			'Niveau sécurité SNMPv3',
	'S_SNMPV3_AUTH_PASSPHRASE'=>			'SNMPv3 auth passphrase',
	'S_SNMPV3_PRIV_PASSPHRASE'=>			'SNMPv3 priv passphrase',
	'S_CUSTOM_MULTIPLIER'=>			'Multiplicateur personnalis',
	'S_DO_NOT_USE'=>			'Ne pas utiliser',
	'S_USE_MULTIPLIER'=>			'Utiliser multiplicateur',
	'S_SELECT_HOST_DOT_DOT_DOT'=>			'Choisir hôte...',
	'S_LOG_TIME_FORMAT'=>			'Format Log time',
	'S_CREATE_ITEM'=>			'Créer item',
	'S_ADD_ITEM'=>			'Ajouter Item',
	'S_X_ELEMENTS_COPY_TO_DOT_DOT_DOT'=>			'éléments copiés de ...',
	'S_MODE'=>			'Mode',
	'S_TARGET'=>			'Cible',
	'S_TARGET_TYPE'=>			'Type de cible',
	'S_SKIP_EXISTING_ITEMS'=>			'Sauter les items existants',
	'S_UPDATE_EXISTING_NON_LINKED_ITEMS'=>			'modifier les items non liés existants',
	'S_COPY'=>			'Copier',
	'S_SHOW_ITEMS_WITH_DESCRIPTION_LIKE'=>			'Montrer les items dont la description est',
	'S_SHOW_DISABLED_ITEMS'=>			'Montrer les items désactivés',
	'S_HIDE_DISABLED_ITEMS'=>			'Cacher les items désactivés',
	'S_HISTORY_CLEANING_CAN_TAKE_A_LONG_TIME_CONTINUE_Q'=>			'Le nettoyage de l\'historique prend du temps. Continuer?',
	'S_ITEM_SELECTION'=>			'Sélection item',
	'S_SELECTION_MODE'=>			'Selection mode',
	'S_ADVANCED'=>			'Advanc',
	'S_MASS_UPDATE'=>			'Modification en masse',
	'S_SEARCH'=>			'Recherche',
	'S_EXTERNAL_FILTER'=>			'Filtre externe',
	'S_ORIGINAL'=>			'Original',
	'S_NEW_FLEXIBLE_INTERVAL'=>			'Nouvel intervalle glissant',
	'S_FLEXIBLE_INTERVALS'=>			'Intervalles glissants (sec)',
	'S_LATEST_EVENTS'=>			'Derniers événements',
	'S_HISTORY_OF_EVENTS_BIG'=>			'HISTORIQUE DES ÉVÉNEMENTS',
	'S_NO_EVENTS_FOUND'=>			'Aucun événement trouvé',
	'S_LAST_CHECK'=>			'Dernière vérification',
	'S_LAST_CHECK_BIG'=>			'DERNIÈRE VÉRIFICATION',
	'S_LAST_VALUE'=>			'Dernière valeur',
	'S_LINK'=>			'Lien',
	'S_LABEL'=>			'Label',
	'S_X'=>			'X',
	'S_Y'=>			'Y',
	'S_ICON_ON'=>			'Icone (marche)',
	'S_ICON_OFF'=>			'Icone (arret)',
	'S_ICON_UNKNOWN'=>			'Icone (indéfini)',
	'S_ELEMENT_1'=>			'Element 1',
	'S_ELEMENT_2'=>			'Element 2',
	'S_LINK_STATUS_INDICATOR'=>			'Indicateur de statut de lien',
	'S_CONFIGURATION_OF_NETWORK_MAPS'=>			'CONFIGURATION DE LA CARTE DES ELEMENTS RESEAU',
	'S_MAPS_BIG'=>			'CARTES',
	'S_NO_MAPS_DEFINED'=>			'Aucune carte définie',
	'S_CREATE_MAP'=>			'Créer carte',
	'S_ICON_LABEL_LOCATION'=>			'Positionnement de l\'icone du label',
	'S_BOTTOM'=>			'Bas',
	'S_TOP'=>			'Haut',
	'S_OK_BIG'=>			'OK',
	'S_PROBLEMS_SMALL'=>			'problèmes',
	'S_ZABBIX_URL'=>			'http://www.zabbix.com',
	'S_NETWORK_MAPS'=>			'Cartes réseau',
	'S_NETWORK_MAPS_BIG'=>			'CARTES RÉSEAU',
	'S_NO_MAPS_TO_DISPLAY'=>			'Aucune carte à afficher',
	'S_SELECT_MAP_TO_DISPLAY'=>			'Choisissez une carte à afficher',
	'S_SELECT_MAP_DOT_DOT_DOT'=>			'Choisissez carte...',
	'S_BACKGROUND_IMAGE'=>			'Image de fond',
	'S_ICON_LABEL_TYPE'=>			'Type étiquette icône',
	'S_LABEL_LOCATION'=>			'Positionnement du label',
	'S_ELEMENT_NAME'=>			'Nom de l\'élément',
	'S_STATUS_ONLY'=>			'Statut seulement',
	'S_NOTHING'=>			'Rien',
	'S_CONFIGURATION_OF_MEDIA_TYPES_BIG'=>			'CONFIGURATION DES TYPES DE MEDIA',
	'S_MEDIA'=>			'Média',
	'S_MEDIA_BIG'=>			'MÉDIA',
	'S_MEDIA_ACTIVATED'=>			'Média activé',
	'S_CANNOT_ACTIVATE_MEDIA'=>			'Impossible d\'activer le média',
	'S_MEDIA_DISABLED'=>			'Média désactivé',
	'S_CANNOT_DISABLE_MEDIA'=>			'Impossible de désactiver le média',
	'S_MEDIA_ADDED'=>			'Média ajouté',
	'S_CANNOT_ADD_MEDIA'=>			'Impossible d\'ajouter le média',
	'S_MEDIA_UPDATED'=>			'Média mis à jour',
	'S_CANNOT_UPDATE_MEDIA'=>			'Impossible de mettre à jour le média',
	'S_MEDIA_DELETED'=>			'Média supprimé',
	'S_CANNOT_DELETE_MEDIA'=>			'Impossible de supprimer média',
	'S_SEND_TO'=>			'Envoyer',
	'S_WHEN_ACTIVE'=>			'Lorsque actif',
	'S_NO_MEDIA_DEFINED'=>			'Aucun média n\'est défini',
	'S_NEW_MEDIA'=>			'Nouveau média',
	'S_USE_IF_SEVERITY'=>			'Utiliser si sévérité',
	'S_DELETE_SELECTED_MEDIA_Q'=>			'Supprimer média sélectionné?',
	'S_CREATE_MEDIA'=>			'Créer un Media',
	'S_SAVE'=>			'Sauver',
	'S_CANCEL'=>			'Annuler',
	'S_MENU_LATEST_VALUES'=>			'DERNIÈRES VALEURS',
	'S_MENU_TRIGGERS'=>			'DÉCLENCHEURS',
	'S_MENU_QUEUE'=>			'QUEUE',
	'S_MENU_ALARMS'=>			'ALARMES',
	'S_MENU_ALERTS'=>			'ALERTES',
	'S_MENU_NETWORK_MAPS'=>			'CARTES RÉSEAU',
	'S_MENU_GRAPHS'=>			'GRAPHIQUES',
	'S_MENU_SCREENS'=>			'ÉCRANS',
	'S_MENU_IT_SERVICES'=>			'SERVICES TI',
	'S_MENU_HOME'=>			'ACCUEIL',
	'S_MENU_ABOUT'=>			'A PROPOS',
	'S_MENU_STATUS_OF_ZABBIX'=>			'STATUT DE ZABBIX',
	'S_MENU_AVAILABILITY_REPORT'=>			'RAPPORT DE DISPONIBILITÉ',
	'S_MENU_CONFIG'=>			'CONFIGURATION',
	'S_MENU_USERS'=>			'UTILISATEURS',
	'S_MENU_HOSTS'=>			'HÔTES',
	'S_MENU_ITEMS'=>			'ITEMS',
	'S_MENU_AUDIT'=>			'AUDIT',
	'S_SWITCH_NODE'=>			'Noeud switch',
	'S_SELECT_GROUP_DOT_DOT_DOT'=>			'Choisir groupe...',
	'S_OVERVIEW'=>			'Aperçu',
	'S_OVERVIEW_BIG'=>			'APERÇU',
	'S_EXCL'=>			'!',
	'S_DATA'=>			'Donnée',
	'S_SHOW_GRAPH_OF_ITEM'=>			'Montrer le graphe des items',
	'S_SHOW_VALUES_OF_ITEM'=>			'Montrer les valeurs des items',
	'S_VALUES'=>			'Valeurs',
	'S_5_MIN'=>			'5 min',
	'S_15_MIN'=>			'15 min',
	'S_QUEUE_BIG'=>			'FILE D\'ATTENTE',
	'S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG'=>			'FILE D\'ATTENTE DES ITEMS A METTRE A JOUR',
	'S_NEXT_CHECK'=>			'Prochaine vérification',
	'S_THE_QUEUE_IS_EMPTY'=>			'La file d\'attente est vide',
	'S_TOTAL'=>			'Total',
	'S_COUNT'=>			'Compte',
	'S_5_SECONDS'=>			'5 secondes',
	'S_10_SECONDS'=>			'10 secondes',
	'S_30_SECONDS'=>			'30 secondes',
	'S_1_MINUTE'=>			'1 minute',
	'S_5_MINUTES'=>			'5 minutes',
	'S_MORE_THAN_5_MINUTES'=>			'Plus de 5 minutes',
	'S_STATUS_OF_ZABBIX'=>			'Statut de ZABBIX',
	'S_STATUS_OF_ZABBIX_BIG'=>			'STATUT DE ZABBIX',
	'S_VALUE'=>			'Valeur',
	'S_ZABBIX_SERVER_IS_RUNNING'=>			'Serveur ZABBIX en fonction',
	'S_NUMBER_OF_VALUES_STORED'=>			'Nombre de valeurs enregistrées',
	'S_VALUES_STORED'=>			'Valeurs stockées',
	'S_NUMBER_OF_TRENDS_STORED'=>			'Nombre de tendance stockées',
	'S_TRENDS_STORED'=>			'Tendances stockées',
	'S_NUMBER_OF_EVENTS'=>			'Nombre d\'événements',
	'S_NUMBER_OF_ALERTS'=>			'Nombre d\'alertes',
	'S_NUMBER_OF_TRIGGERS'=>			'Nombre de triggers (enabled/disabled)[true/unknown/false]',
	'S_NUMBER_OF_TRIGGERS_SHORT'=>			'Triggers (s/ns)[v/u/f]',
	'S_NUMBER_OF_ITEMS'=>			'Nombre d\'items (surveillés/non surveillés/not supportés)[trapper]',
	'S_NUMBER_OF_ITEMS_SHORT'=>			'Items (s/ns/nosup)[t]',
	'S_NUMBER_OF_USERS'=>			'Nombre d\'utilisateurs',
	'S_NUMBER_OF_USERS_SHORT'=>			'Users (online)',
	'S_NUMBER_OF_HOSTS'=>			'Nombre d\'hotes (surveillés/non surveillés/modèles/supprimés)',
	'S_NUMBER_OF_HOSTS_SHORT'=>			'Hotes (m/n/t/d)',
	'S_YES'=>			'Oui',
	'S_NO'=>			'Non',
	'S_RUNNING'=>			'En marche',
	'S_NOT_RUNNING'=>			'A l\'arret',
	'S_AVAILABILITY_REPORT'=>			'Rapport de disponibilité',
	'S_AVAILABILITY_REPORT_BIG'=>			'RAPPORT DE DISPONIBILITÉ',
	'S_SHOW'=>			'Afficher',
	'S_TRUE'=>			'Vrai',
	'S_FALSE'=>			'Faux',
	'S_IT_SERVICES_AVAILABILITY_REPORT'=>			'Rapport de disponibilité des services IT',
	'S_IT_SERVICES_AVAILABILITY_REPORT_BIG'=>			'RAPPORT DE DISPONIBILITÉ DES SERVICES TI',
	'S_FROM'=>			'De',
	'S_FROM_SMALL'=>			'de',
	'S_TILL'=>			'A',
	'S_OK'=>			'Ok',
	'S_PROBLEMS'=>			'Problèmes',
	'S_PERCENTAGE'=>			'Pourcentage',
	'S_SLA'=>			'Disponibilité',
	'S_DAY'=>			'Jour',
	'S_MONTH'=>			'Mois',
	'S_YEAR'=>			'Année',
	'S_DAILY'=>			'Journalier',
	'S_WEEKLY'=>			'Hebdomadaire',
	'S_MONTHLY'=>			'Mensuel',
	'S_YEARLY'=>			'Annuel',
	'S_NOTIFICATIONS'=>			'Notifications',
	'S_NOTIFICATIONS_BIG'=>			'NOTIFICATIONS',
	'S_IT_NOTIFICATIONS'=>			'Rapport de notification',
	'S_TRIGGERS_TOP_100'=>			'Le top 100 des déclencheurs',
	'S_TRIGGERS_TOP_100_BIG'=>			'LE TOP 100 DS DECLENCHEURS',
	'S_NUMBER_OF_STATUS_CHANGES'=>			'Nombre de statuts modifiés',
	'S_WEEK'=>			'Semaine',
	'S_LAST'=>			'Dernier',
	'S_SCREENS'=>			'Écrans',
	'S_SCREEN'=>			'Écran',
	'S_CONFIGURATION_OF_SCREENS_BIG'=>			'CONFIGURATION DES ÉCRANS',
	'S_CONFIGURATION_OF_SCREENS'=>			'Configuration des écrans',
	'S_SCREEN_ADDED'=>			'Écran ajouté',
	'S_CANNOT_ADD_SCREEN'=>			'Impossible d\'ajouter l\'écran',
	'S_SCREEN_UPDATED'=>			'Écran actualisé',
	'S_CANNOT_UPDATE_SCREEN'=>			'Impossible d\'actualiser l\'écran',
	'S_SCREEN_DELETED'=>			'Écran supprimé',
	'S_CANNOT_DELETE_SCREEN'=>			'Impossible de supprimer l\'écran',
	'S_COLUMNS'=>			'Colonnes',
	'S_ROWS'=>			'Lignes',
	'S_NO_SCREENS_DEFINED'=>			'Aucun écran n\'est défini',
	'S_DELETE_SCREEN_Q'=>			'Supprimer écran?',
	'S_CONFIGURATION_OF_SCREEN_BIG'=>			'CONFIGURATION DE L\'ÉCRAN',
	'S_SCREEN_CELL_CONFIGURATION'=>			'Configuration cellule écran',
	'S_RESOURCE'=>			'Ressource',
	'S_RESOURCES'=>			'Ressources',
	'S_RESOURCE_TYPE'=>			'Type de ressource',
	'S_RIGHTS_OF_RESOURCES'=>			'Droits utilisateur',
	'S_NO_RESOURCES_DEFINED'=>			'Aucune ressource définie',
	'S_SIMPLE_GRAPH'=>			'Graphique simple',
	'S_GRAPH_NAME'=>			'Nom du graphique',
	'S_WIDTH'=>			'Largeur',
	'S_HEIGHT'=>			'Hauteur',
	'S_CREATE_SCREEN'=>			'Créer écran',
	'S_EDIT'=>			'Edition',
	'S_DIMENSION_COLS_ROWS'=>			'Dimension (cols x lignes)',
	'S_SLIDESHOWS'=>			'Slides',
	'S_SLIDESHOW'=>			'Slide',
	'S_CONFIGURATION_OF_SLIDESHOWS_BIG'=>			'CONFIGURATION DES SLIDES',
	'S_SLIDESHOWS_BIG'=>			'SLIDES',
	'S_NO_SLIDESHOWS_DEFINED'=>			'Aucune slide défini',
	'S_COUNT_OF_SLIDES'=>			'Nombre de slides',
	'S_NO_SLIDES_DEFINED'=>			'Pas de slide défini',
	'S_SLIDES'=>			'Slides',
	'S_NEW_SLIDE'=>			'Nouveau slide',
	'S_MAP'=>			'Carte',
	'S_AS_PLAIN_TEXT'=>			'Format texte',
	'S_PLAIN_TEXT'=>			'Texte brut',
	'S_COLUMN_SPAN'=>			'Étendue de la colonne',
	'S_ROW_SPAN'=>			'Étendue de la ligne',
	'S_SHOW_LINES'=>			'Montrer les lignes',
	'S_HOSTS_INFO'=>			'Informations hotes',
	'S_TRIGGERS_INFO'=>			'Informations déclencheurs',
	'S_SERVER_INFO'=>			'Informations serveur',
	'S_CLOCK'=>			'Horloge',
	'S_TRIGGERS_OVERVIEW'=>			'Aperçu déclencheurs',
	'S_DATA_OVERVIEW'=>			'Aperçu données',
	'S_HISTORY_OF_ACTIONS'=>			'Historique des actions',
	'S_HISTORY_OF_EVENTS'=>			'Historique des événements',
	'S_TIME_TYPE'=>			'Type temps',
	'S_SERVER_TIME'=>			'Temps serveur',
	'S_LOCAL_TIME'=>			'Temps local',
	'S_STYLE'=>			'Style',
	'S_VERTICAL'=>			'Vertical',
	'S_HORISONTAL'=>			'Horizontal',
	'S_HORISONTAL_ALIGN'=>			'Alignement horizontal',
	'S_CENTER'=>			'Centre',
	'S_RIGHT'=>			'Droit',
	'S_VERTICAL_ALIGN'=>			'Alignement vertical',
	'S_MIDDLE'=>			'Milieu',
	'S_CUSTOM_SCREENS'=>			'Écrans personnalisés',
	'S_SCREENS_BIG'=>			'ÉCRANS',
	'S_NO_SCREENS_TO_DISPLAY'=>			'Aucun écran à afficher',
	'S_SELECT_SCREEN_TO_DISPLAY'=>			'Sélectionnez l\'écran à afficher',
	'S_SELECT_SCREEN_DOT_DOT_DOT'=>			'Sélectionnez l\'écran ...',
	'S_SLIDESHOW_UPDATED'=>			'Slide modifi',
	'S_CANNOT_UPDATE_SLIDESHOW'=>			'Impossible de modifier le slide',
	'S_SLIDESHOW_ADDED'=>			'Slide ajout',
	'S_CANNOT_ADD_SLIDESHOW'=>			'Impossible d\'ajouter le slide',
	'S_SLIDESHOW_DELETED'=>			'Slide supprim',
	'S_CANNOT_DELETE_SLIDESHOW'=>			'Impossible de supprimer le slide',
	'S_DELETE_SLIDESHOW_Q'=>			'Supprimer le slide?',
	'S_ROOT_SMALL'=>			'root',
	'S_IT_SERVICE'=>			'Service IT',
	'S_IT_SERVICES'=>			'Services TI',
	'S_SERVICE_UPDATED'=>			'Service actualis',
	'S_CANNOT_UPDATE_SERVICE'=>			'Impossible d\'actualiser le service',
	'S_SERVICE_ADDED'=>			'Service ajout',
	'S_CANNOT_ADD_SERVICE'=>			'Impossible d\'ajouter le service',
	'S_LINK_ADDED'=>			'Lien ajout',
	'S_CANNOT_ADD_LINK'=>			'Impossible d\'ajouter le lien',
	'S_SERVICE_DELETED'=>			'Service supprim',
	'S_CANNOT_DELETE_SERVICE'=>			'Impossible de supprimer le service',
	'S_LINK_DELETED'=>			'Lien supprim',
	'S_CANNOT_DELETE_LINK'=>			'Impossible de supprimer le lien',
	'S_STATUS_CALCULATION'=>			'Calcul du statut',
	'S_STATUS_CALCULATION_ALGORITHM'=>			'Algorithme de calcul du statut',
	'S_NONE'=>			'Aucun',
	'S_MAX_OF_CHILDS'=>			'MAX des enfants',
	'S_MIN_OF_CHILDS'=>			'MIN des enfants',
	'S_SERVICE_1'=>			'Service 1',
	'S_SERVICE_2'=>			'Service 2',
	'S_SOFT_HARD_LINK'=>			'Lien souple/rigide',
	'S_SOFT'=>			'Souple',
	'S_HARD'=>			'Rigide',
	'S_DO_NOT_CALCULATE'=>			'Ne pas calculer',
	'S_MAX_BIG'=>			'MAX',
	'S_MIN_BIG'=>			'MIN',
	'S_SHOW_SLA'=>			'Afficher disponibilité',
	'S_ACCEPTABLE_SLA_IN_PERCENT'=>			'Disponibilité acceptable (en %)',
	'S_LINK_TO_TRIGGER_Q'=>			'Lier au déclencheur?',
	'S_SORT_ORDER_0_999'=>			'Ordre de tri (0->999)',
	'S_DELETE_SERVICE_Q'=>			'Suppression service?',
	'S_LINK_TO'=>			'Lier',
	'S_SOFT_LINK_Q'=>			'Lien souple?',
	'S_ADD_SERVER_DETAILS'=>			'Ajouter détails au serveur',
	'S_TRIGGER'=>			'Déclencheur',
	'S_SERVER'=>			'Serveur',
	'S_DELETE'=>			'Supprimer',
	'S_CLONE'=>			'Clone',
	'S_DELETE_SELECTED_SERVICES'=>			'Suppression des services sélectionnés?',
	'S_DELETE_SELECTED_LINKS'=>			'Suppression des liens sélectionnés?',
	'S_SERVICES_DELETED'=>			'Services supprimés',
	'S_CANNOT_DELETE_SERVICES'=>			'Impossible de supprimer les services',
	'S_UPTIME'=>			'Uptime',
	'S_DOWNTIME'=>			'Downtime',
	'S_ONE_TIME_DOWNTIME'=>			'One-time downtime',
	'S_NO_TIMES_DEFINED'=>			'Aucun temps défini',
	'S_SERVICE_TIMES'=>			'Temps de service',
	'S_NEW_SERVICE_TIME'=>			'Nouveau temps de service',
	'S_NOTE'=>			'Note',
	'S_SOFT_LINK'=>			'Lien Soft',
	'S_REMOVE'=>			'Supprimer',
	'S_DEPENDS_ON'=>			'Dépend de',
	'S_SUNDAY'=>			'Dimanche',
	'S_MONDAY'=>			'Lundi',
	'S_TUESDAY'=>			'Mardi',
	'S_WEDNESDAY'=>			'Mercredi',
	'S_THURSDAY'=>			'Jeudi',
	'S_FRIDAY'=>			'Vendredi',
	'S_SATURDAY'=>			'Samedi',
	'S_IT_SERVICES_BIG'=>			'SERVICES TI',
	'S_SERVICE'=>			'Service',
	'S_SERVICES'=>			'Services',
	'S_REASON'=>			'Raison',
	'S_SLA_LAST_7_DAYS'=>			'DISPONIBILITÉ (7 derniers jours)',
	'S_PLANNED_CURRENT_SLA'=>			'Disponibilité planifiée/actuelle',
	'S_TRIGGER_BIG'=>			'DÉCLENCHEUR',
	'S_NO_TRIGGER'=>			'Pas de déclencheur',
	'S_NO_TRIGGERS_DEFINED'=>			'Aucun déclencheur défini',
	'S_CONFIGURATION_OF_TRIGGERS'=>			'Configuration des déclencheurs',
	'S_CONFIGURATION_OF_TRIGGERS_BIG'=>			'CONFIGURATION DES DÉCLENCHEURS',
	'S_DEPENDENCY_ADDED'=>			'Dépendance ajoutée',
	'S_CANNOT_ADD_DEPENDENCY'=>			'Impossible d\'ajouter la dépendance',
	'S_TRIGGERS_UPDATED'=>			'Déclencheurs actualisés',
	'S_CANNOT_UPDATE_TRIGGERS'=>			'Impossible d\'actualiser les déclencheurs',
	'S_TRIGGERS_DISABLED'=>			'Déclencheurs désactivés',
	'S_CANNOT_DISABLE_TRIGGERS'=>			'Impossible de désactiver les déclencheurs',
	'S_TRIGGERS_DELETED'=>			'Déclencheurs supprimés',
	'S_CANNOT_DELETE_TRIGGERS'=>			'Impossible de supprimer les déclencheurs',
	'S_TRIGGER_DELETED'=>			'Déclencheur supprimé',
	'S_CANNOT_DELETE_TRIGGER'=>			'Impossible de supprimer le déclencheur',
	'S_INVALID_TRIGGER_EXPRESSION'=>			'Définition du déclencheur non valide',
	'S_TRIGGER_ADDED'=>			'Déclencheur ajouté',
	'S_CANNOT_ADD_TRIGGER'=>			'Impossible d\'ajouter le déclencheur',
	'S_SEVERITY'=>			'Sévérité',
	'S_EXPRESSION'=>			'Expression',
	'S_DISABLED'=>			'Désactivé',
	'S_ENABLED'=>			'Activ',
	'S_ENABLE_SELECTED'=>			'Activer les éléments sélectionnés',
	'S_ENABLE_SELECTED_TRIGGERS_Q'=>			'Activer les déclencheurs sélectionnés?',
	'S_DISABLE_SELECTED_TRIGGERS_Q'=>			'Désactiver les déclencheurs sélectionnés?',
	'S_DELETE_SELECTED_TRIGGERS_Q'=>			'Supprimer les déclencheurs sélectionnés?',
	'S_CHANGE'=>			'Changer',
	'S_TRIGGER_UPDATED'=>			'Déclencheur mis à jour',
	'S_CANNOT_UPDATE_TRIGGER'=>			'Impossible d\'actualiser le déclencheur',
	'S_URL'=>			'URL',
	'S_INVALID_URL'=>			'URL invalide',
	'S_CREATE_TRIGGER'=>			'Créer déclencheur',
	'S_INSERT'=>			'Insertion',
	'S_TIMES'=>			'Temps',
	'S_SECONDS'=>			'Secondes',
	'S_SEC_SMALL'=>			'sec',
	'S_COUNTS'=>			'Nb',
	'S_LAST_OF'=>			'Dernier',
	'S_SHOW_DISABLED_TRIGGERS'=>			'Montrer les déclencheurs désactivés',
	'S_HIDE_DISABLED_TRIGGERS'=>			'Cacher les déclencheurs désactivés',
	'S_TRIGGER_COMMENTS'=>			'Commentaires sur déclencheur',
	'S_TRIGGER_COMMENTS_BIG'=>			'COMMENTAIRES SUR DÉCLENCHEUR',
	'S_COMMENT_UPDATED'=>			'Commentaire actualis',
	'S_CANNOT_UPDATE_COMMENT'=>			'Impossible d\'actualiser le commentaire',
	'S_ADD'=>			'Ajouter',
	'S_STATUS_OF_TRIGGERS'=>			'Statut des déclencheurs',
	'S_STATUS_OF_TRIGGERS_BIG'=>			'STATUT DES DÉCLENCHEURS',
	'S_SHOW_ONLY_TRUE'=>			'Afficher seulement si vrai',
	'S_HIDE_ACTIONS'=>			'Cacher les actions',
	'S_SHOW_ACTIONS'=>			'Afficher les actions',
	'S_HIDE_DETAILS'=>			'Cacher les détails',
	'S_SHOW_DETAILS'=>			'Afficher les détails',
	'S_SELECT'=>			'Sélectionner',
	'S_HIDE_SELECT'=>			'Cacher la sélection',
	'S_TRIGGERS_BIG'=>			'DÉCLENCHEURS',
	'S_NAME_BIG'=>			'NOM',
	'S_SEVERITY_BIG'=>			'SÉVÉRITÉ',
	'S_LAST_CHANGE_BIG'=>			'DERNIER CHANGEMENT',
	'S_LAST_CHANGE'=>			'Dernier changement',
	'S_COMMENTS'=>			'Commentaires',
	'S_ACKNOWLEDGED'=>			'Acquittement',
	'S_ACK'=>			'Acquit',
	'S_NEVER'=>			'Jamais',
	'S_ZABBIX_USER'=>			'Utilisateur Zabbix',
	'S_ZABBIX_ADMIN'=>			'Administrateur Zabbix',
	'S_SUPER_ADMIN'=>			'Super Administrateur Zabbix',
	'S_USER_TYPE'=>			'Type utilisateur',
	'S_USERS'=>			'Utilisateurs',
	'S_USER_ADDED'=>			'Utilisateur ajout',
	'S_CANNOT_ADD_USER'=>			'Impossible d\'ajouter l\'utilisateur',
	'S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST'=>			'Impossible d\'ajouter l\'utilisateur. Les mots de passe doivent être identiques.',
	'S_USER_DELETED'=>			'Utilisateur supprim',
	'S_CANNOT_DELETE_USER'=>			'Impossible de supprimer l\'utilisateur',
	'S_PERMISSION_DELETED'=>			'Permission retirée',
	'S_CANNOT_DELETE_PERMISSION'=>			'Impossible de retirer la permission',
	'S_PERMISSION_ADDED'=>			'Permission ajoutée',
	'S_CANNOT_ADD_PERMISSION'=>			'Impossible d\'ajouter la permission',
	'S_USER_UPDATED'=>			'Utilisateur actualis',
	'S_ONLY_FOR_GUEST_ALLOWED_EMPTY_PASSWORD'=>			'Seulement l\'utilisateur guest peut avoir un mot d epasse vide.',
	'S_CANNOT_UPDATE_USER'=>			'Impossible d\'actualiser l\'utilisateur',
	'S_CANNOT_UPDATE_USER_BOTH_PASSWORDS'=>			'Impossible d\'actualiser l\'utilisateur. Les mots de passe doivent être identiques.',
	'S_GROUP_ADDED'=>			'Groupe ajout',
	'S_CANNOT_ADD_GROUP'=>			'Impossible d\'ajouter le groupe',
	'S_GROUP_UPDATED'=>			'Groupe actualis',
	'S_CANNOT_UPDATE_GROUP'=>			'Impossible d\'actualiser le groupe',
	'S_GROUP_DELETED'=>			'Groupe supprim',
	'S_CANNOT_DELETE_GROUP'=>			'Impossible de supprimer le groupe',
	'S_CONFIGURATION_OF_USERS_AND_USER_GROUPS'=>			'CONFIGURATION DES UTILISATEURS ET DES GROUPES',
	'S_USER_GROUPS_BIG'=>			'GROUPES D\'UTILISATEURS',
	'S_USERS_BIG'=>			'UTILISATEURS',
	'S_USER_GROUPS'=>			'Groupes d\'utilisateurs',
	'S_MEMBERS'=>			'Membres',
	'S_HOSTS_TEMPLATES_LINKAGE'=>			'Liens hôtes/modèles',
	'S_CONFIGURATION_OF_TEMPLATES_LINKAGE'=>			'CONFIGURATION DES LIENS DE MODÈLES',
	'S_LINKED_TEMPLATES_BIG'=>			'MODÈLES LIÉS',
	'S_NO_USER_GROUPS_DEFINED'=>			'Aucun groupe utilisateur n\'est défini',
	'S_ALIAS'=>			'Alias',
	'S_NAME'=>			'Nom',
	'S_SURNAME'=>			'Prénom',
	'S_IS_ONLINE_Q'=>			'Est connecté?',
	'S_NO_USERS_DEFINED'=>			'Aucun utilisateur défini',
	'S_PERMISSION'=>			'Permission',
	'S_RIGHTS'=>			'Droits',
	'S_NO_RIGHTS_DEFINED'=>			'Aucun droit défini',
	'S_RESOURCE_NAME'=>			'Nom de la ressource',
	'S_READ_ONLY'=>			'Lecture seule',
	'S_READ_WRITE'=>			'Lecture-écriture',
	'S_DENY'=>			'Interdit',
	'S_HIDE'=>			'Cacher',
	'S_PASSWORD'=>			'Mot de passe',
	'S_CHANGE_PASSWORD'=>			'Changer le mot de passe',
	'S_PASSWORD_ONCE_AGAIN'=>			'Mot de passe (une autre fois)',
	'S_URL_AFTER_LOGIN'=>			'URL (après connexion)',
	'S_AUTO_LOGOUT_IN_SEC'=>			'Déconnection automatique (dans =>0 secondes - désactiver)',
	'S_SCREEN_REFRESH'=>			'Refresh (in seconds)',
	'S_CREATE_USER'=>			'Création utilisateur',
	'S_CREATE_GROUP'=>			'Création groupe',
	'S_DELETE_SELECTED_USERS_Q'=>			'Suppression des utilisateurs sélectionnés?',
	'S_NO_ACCESSIBLE_RESOURCES'=>			'Aucune ressource accessible',
	'S_AUDIT_LOG'=>			'Journal de vérification',
	'S_AUDIT_LOG_BIG'=>			'JOURNAL DE VÉRIFICATION',
	'S_ACTION'=>			'Action',
	'S_DETAILS'=>			'Détails',
	'S_UNKNOWN_ACTION'=>			'Action inconnue',
	'S_ADDED'=>			'Ajout',
	'S_UPDATED'=>			'Actualis',
	'S_LOGGED_IN'=>			'Connect',
	'S_LOGGED_OUT'=>			'Déconnecté',
	'S_MEDIA_TYPE'=>			'Type de média',
	'S_GRAPH_ELEMENT'=>			'Élément graphique',
	'S_UNKNOWN_RESOURCE'=>			'Ressource inconnue',
	'S_USER_PROFILE_BIG'=>			'PROFIL UTILISATEUR',
	'S_USER_PROFILE'=>			'Profil utilisateur',
	'S_LANGUAGE'=>			'Langue',
	'S_ENGLISH_GB'=>			'Anglais (GB)',
	'S_FRENCH_FR'=>			'Français (FR)',
	'S_GERMAN_DE'=>			'Allemand (DE)',
	'S_ITALIAN_IT'=>			'Italien (IT)',
	'S_LATVIAN_LV'=>			'Letton (LV)',
	'S_RUSSIAN_RU'=>			'Russe (RU)',
	'S_SPANISH_SP'=>			'Espagnol (SP)',
	'S_SWEDISH_SE'=>			'Suédois (SE)',
	'S_JAPANESE_JP'=>			'Japonais (JP)',
	'S_CHINESE_CN'=>			'Chinois (CN)',
	'S_DUTCH_NL'=>			'Hollandais (NL)',
	'S_ZABBIX_BIG'=>			'ZABBIX',
	'S_HOST_PROFILES'=>			'Profils serveurs',
	'S_HOST_PROFILES_BIG'=>			'PROFILS SERVEURS',
	'S_EMPTY'=>			'Vide',
	'S_STANDARD_ITEMS_BIG'=>			'ITEMS STANDARDS',
	'S_NO_ITEMS'=>			'Aucun item',
	'S_HELP'=>			'Aide',
	'S_PROFILE'=>			'Profil',
	'S_GET_SUPPORT'=>			'Accès support',
	'S_MONITORING'=>			'Métriques',
	'S_INVENTORY'=>			'Inventaire',
	'S_QUEUE'=>			'File d\'attente',
	'S_EVENTS'=>			'Evénements',
	'S_EVENTS_BIG'=>			'EVENEMENTS',
	'S_MAPS'=>			'Cartes',
	'S_REPORTS'=>			'Rapports',
	'S_GENERAL'=>			'Général',
	'S_AUDIT'=>			'Audit',
	'S_LOGIN'=>			'Login',
	'S_LOGOUT'=>			'Logout',
	'S_LATEST_DATA'=>			'Dernières métriques',
	'S_INCORRECT_DESCRIPTION'=>			'Description incorrecte',
	'S_CANT_FORMAT_TREE'=>			'Production arbre de tri impossible',
	
	);
?>